@@ -23,6 +23,8 @@
 #'
 #' @template section_progress_bars
 #' @template section_logging
+#' @templateVar optimizer bbotk::OptimizerCmaes
+#' @template section_optimizer
 #'
 #' @source
 #' `r format_bib("hansen_2016")`
@@ -69,9 +71,9 @@ TunerCmaes = R6Class("TunerCmaes",
    #' Creates a new instance of this [R6][R6::R6Class] class.
    initialize = function() {
      super$initialize(
-       optimizer = OptimizerCmaes$new()
+       optimizer = OptimizerCmaes$new(),
+       man = "mlr3tuning::mlr_tuners_cmaes"
      )
-     private$.man = "mlr3tuning::mlr_tuners_cmaes"
    }
   )
 )
