@@ -22,6 +22,7 @@
 #' @template param_store_models
 #' @template param_allow_hotstart
 #' @template param_keep_hotstart_stack
+#' @template param_evaluate_default
 #'
 #' @export
 #' @examples
@@ -37,7 +38,7 @@
 #'
 #' # apply hyperparameter values to learner
 #' learner$param_set$values = instance$result_learner_param_vals
-tune = function(method, task, learner, resampling, measures = NULL, term_evals = NULL, term_time = NULL, search_space = NULL, store_models = FALSE, allow_hotstart = FALSE, keep_hotstart_stack = FALSE, ...) {
+tune = function(method, task, learner, resampling, measures = NULL, term_evals = NULL, term_time = NULL, search_space = NULL, store_models = FALSE, allow_hotstart = FALSE, keep_hotstart_stack = FALSE, evaluate_default = FALSE, ...) {
   tuner = if (is.character(method)) {
     assert_choice(method, mlr_tuners$keys())
     tnr(method, ...)
@@ -46,15 +47,8 @@ tune = function(method, task, learner, resampling, measures = NULL, term_evals =
   }
   terminator = terminator_selection(term_evals, term_time)
 
-  if (!is.list(measures)) {
-    instance = TuningInstanceSingleCrit$new(task = task, learner = learner, resampling = resampling,
-      measure = measures, terminator = terminator, search_space = search_space, store_models = store_models,
-      allow_hotstart = allow_hotstart, keep_hotstart_stack = keep_hotstart_stack)
-  } else {
-    instance = TuningInstanceMultiCrit$new(task = task, learner = learner, resampling = resampling, measures = measures,
-      terminator = terminator, search_space = search_space, store_models = store_models,
-      allow_hotstart = allow_hotstart, keep_hotstart_stack = keep_hotstart_stack)
-  }
+  TuningInstance = if (!is.list(measures)) TuningInstanceSingleCrit else TuningInstanceMultiCrit
+  instance = TuningInstance$new(task, learner, resampling, measures, terminator, search_space, store_models = store_models, allow_hotstart = allow_hotstart, keep_hotstart_stack = keep_hotstart_stack, evaluate_default = evaluate_default)
 
   tuner$optimize(instance)
   instance
@@ -74,3 +68,4 @@ terminator_selection = function(term_evals, term_time) {
     trm("run_time", secs = term_time)
   }
 }
+
