@@ -7,7 +7,7 @@ test_that("hotstart works forwards", {
     task = task,
     learner = learner,
     resampling = rsmp("holdout"),
-    measure = msr("classif.ce"),
+    measures = msr("classif.ce"),
     batch_size = 5,
     resolution = 5,
     store_models = TRUE,
@@ -30,7 +30,7 @@ test_that("hotstart works backwards", {
     task = task,
     learner = learner,
     resampling = rsmp("holdout"),
-    measure = msr("classif.ce"),
+    measures = msr("classif.ce"),
     batch_size = 5,
     resolution = 5,
     store_models = TRUE,
@@ -53,7 +53,7 @@ test_that("hotstart works forwards and backwards", {
     task = task,
     learner = learner,
     resampling = rsmp("holdout"),
-    measure = msr("classif.ce"),
+    measures = msr("classif.ce"),
     batch_size = 5,
     resolution = 5,
     store_models = TRUE,
@@ -75,7 +75,7 @@ test_that("hotstart flag is not set to TRUE if learners does not support hotstar
     task = task,
     learner = learner,
     resampling = rsmp("holdout"),
-    measure = msr("classif.ce"),
+    measures = msr("classif.ce"),
     batch_size = 5,
     resolution = 5,
     store_models = TRUE,
@@ -94,7 +94,7 @@ test_that("models are discarded after storing them in the stack", {
     task = task,
     learner = learner,
     resampling = rsmp("holdout"),
-    measure = msr("classif.ce"),
+    measures = msr("classif.ce"),
     batch_size = 5,
     resolution = 5,
     store_models = FALSE,
@@ -119,7 +119,7 @@ test_that("objects are cloned", {
     task = task,
     learner = learner,
     resampling = rsmp("holdout"),
-    measure = msr("classif.ce"),
+    measures = msr("classif.ce"),
     batch_size = 5,
     resolution = 5,
     allow_hotstart = TRUE,
